@@ -20,6 +20,7 @@
 
 #include "config.h"
 
+#include <glib/gi18n-lib.h>
 #include <adwaita.h>
 
 #include "panel-dock.h"
@@ -49,6 +50,9 @@ panel_init (void)
 
   adw_init ();
 
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+
   g_resources_register (panel_get_resource ());
 
   g_type_ensure (PANEL_TYPE_AREA);
