@@ -21,6 +21,7 @@
 #include "config.h"
 
 #include "panel-save-delegate.h"
+#include "panel-util-private.h"
 
 typedef struct
 {
@@ -423,7 +424,7 @@ panel_save_delegate_set_icon_name (PanelSaveDelegate *self,
 
   g_return_if_fail (PANEL_IS_SAVE_DELEGATE (self));
 
-  if (g_set_str (&priv->icon_name, icon_name))
+  if (panel_set_str (&priv->icon_name, icon_name))
     {
       if (g_set_object (&priv->icon, NULL))
         g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_ICON]);
@@ -465,7 +466,7 @@ panel_save_delegate_set_subtitle (PanelSaveDelegate *self,
 
   g_return_if_fail (PANEL_IS_SAVE_DELEGATE (self));
 
-  if (g_set_str (&priv->subtitle, subtitle))
+  if (panel_set_str (&priv->subtitle, subtitle))
     g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_SUBTITLE]);
 }
 
@@ -502,7 +503,7 @@ panel_save_delegate_set_title (PanelSaveDelegate *self,
 
   g_return_if_fail (PANEL_IS_SAVE_DELEGATE (self));
 
-  if (g_set_str (&priv->title, title))
+  if (panel_set_str (&priv->title, title))
     g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_TITLE]);
 }
 
