@@ -28,6 +28,8 @@
 #include "panel-save-dialog.h"
 #include "panel-save-dialog-row-private.h"
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+
 struct _PanelSaveDialog
 {
   AdwMessageDialog     parent_instance;
@@ -75,7 +77,7 @@ save_free (gpointer data)
  *
  * Create a new #PanelSaveDialog.
  *
- * Returns: (transfer full): a newly created #PanelSaveDialog
+ * Returns: a newly created #PanelSaveDialog
  */
 GtkWidget *
 panel_save_dialog_new (void)
@@ -174,8 +176,10 @@ panel_save_dialog_response_save_cb (PanelSaveDialog *self,
   g_assert (PANEL_IS_SAVE_DIALOG (self));
   g_assert (self->task != NULL);
 
-  adw_message_dialog_set_response_enabled (ADW_MESSAGE_DIALOG (self), "save", FALSE);
-  adw_message_dialog_set_response_enabled (ADW_MESSAGE_DIALOG (self), "discard", FALSE);
+  if (adw_message_dialog_has_response (ADW_MESSAGE_DIALOG (self), "save"))
+    adw_message_dialog_set_response_enabled (ADW_MESSAGE_DIALOG (self), "save", FALSE);
+  if (adw_message_dialog_has_response (ADW_MESSAGE_DIALOG (self), "discard"))
+    adw_message_dialog_set_response_enabled (ADW_MESSAGE_DIALOG (self), "discard", FALSE);
 
   self->saving = TRUE;
 
@@ -207,51 +211,6 @@ panel_save_dialog_response_save_cb (PanelSaveDialog *self,
     g_task_return_boolean (self->task, TRUE);
 }
 
-static void
-find_button_and_set_visible (GtkWidget  *parent,
-                             const char *label,
-                             gboolean    visible)
-{
-  g_assert (!parent || GTK_IS_WIDGET (parent));
-
-  for (GtkWidget *child = gtk_widget_get_first_child (parent);
-       child != NULL;
-       child = gtk_widget_get_next_sibling (child))
-    {
-      if (GTK_IS_BUTTON (child) &&
-          g_strcmp0 (label, gtk_button_get_label (GTK_BUTTON (child))) == 0)
-        {
-          gtk_widget_set_visible (child, visible);
-          break;
-        }
-    }
-}
-
-static void
-set_response_visible (AdwMessageDialog *dialog,
-                      const char       *response,
-                      gboolean          visible)
-{
-  const char *label;
-  GObject *wide;
-  GObject *narrow;
-
-  g_assert (ADW_IS_MESSAGE_DIALOG (dialog));
-  g_assert (response != NULL);
-  g_assert (adw_message_dialog_has_response (dialog, response));
-
-  adw_message_dialog_set_response_enabled (dialog, response, visible);
-
-  if (!(label = adw_message_dialog_get_response_label (dialog, response)))
-    return;
-
-  if ((wide = gtk_widget_get_template_child (GTK_WIDGET (dialog), ADW_TYPE_MESSAGE_DIALOG, "wide_response_box")))
-    find_button_and_set_visible (GTK_WIDGET (wide), label, visible);
-
-  if ((narrow = gtk_widget_get_template_child (GTK_WIDGET (dialog), ADW_TYPE_MESSAGE_DIALOG, "narrow_response_box")))
-    find_button_and_set_visible (GTK_WIDGET (narrow), label, visible);
-}
-
 static gboolean
 panel_save_dialog_close_request_idle_cb (gpointer user_data)
 {
@@ -352,6 +311,8 @@ panel_save_dialog_class_init (PanelSaveDialogClass *klass)
    * PanelSaveDialog:close-after-save:
    *
    * This property requests that the widget close after saving.
+   *
+   * Deprecated: 1.8: Use [class@PanelChangesDialog]
    */
   properties [PROP_CLOSE_AFTER_SAVE] =
     g_param_spec_boolean ("close-after-save", NULL, NULL,
@@ -386,6 +347,11 @@ panel_save_dialog_update (PanelSaveDialog *self)
 {
   g_assert (PANEL_IS_SAVE_DIALOG (self));
 
+  if (adw_message_dialog_has_response (ADW_MESSAGE_DIALOG (self), "discard"))
+    adw_message_dialog_remove_response (ADW_MESSAGE_DIALOG (self), "discard");
+  if (adw_message_dialog_has_response (ADW_MESSAGE_DIALOG (self), "save"))
+    adw_message_dialog_remove_response (ADW_MESSAGE_DIALOG (self), "save");
+
   if (self->rows->len == 1)
     {
       PanelSaveDialogRow *row = g_ptr_array_index (self->rows, 0);
@@ -405,13 +371,11 @@ panel_save_dialog_update (PanelSaveDialog *self)
                                           _("Save or Discard Draft?"));
           adw_message_dialog_set_body (ADW_MESSAGE_DIALOG (self), body);
 
+          adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (self), "discard", _("_Discard"));
           adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (self), "discard", ADW_RESPONSE_DESTRUCTIVE);
-          adw_message_dialog_set_response_label (ADW_MESSAGE_DIALOG (self), "discard", _("_Discard"));
-          set_response_visible (ADW_MESSAGE_DIALOG (self), "discard", TRUE);
 
+          adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (self), "save", _("_Save As…"));
           adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (self), "save", ADW_RESPONSE_SUGGESTED);
-          adw_message_dialog_set_response_label (ADW_MESSAGE_DIALOG (self), "save", _("_Save As…"));
-          set_response_visible (ADW_MESSAGE_DIALOG (self), "save", TRUE);
 
           g_free (body);
         }
@@ -427,18 +391,16 @@ panel_save_dialog_update (PanelSaveDialog *self)
                                           _("Save or Discard Changes?"));
           adw_message_dialog_set_body (ADW_MESSAGE_DIALOG (self), body);
 
+          adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (self), "discard", _("_Discard"));
           adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (self), "discard", ADW_RESPONSE_DESTRUCTIVE);
-          adw_message_dialog_set_response_label (ADW_MESSAGE_DIALOG (self), "discard", _("_Discard"));
-          set_response_visible (ADW_MESSAGE_DIALOG (self), "discard", TRUE);
 
+          adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (self), "save", _("_Save"));
           adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (self), "save", ADW_RESPONSE_SUGGESTED);
-          adw_message_dialog_set_response_label (ADW_MESSAGE_DIALOG (self), "save", _("_Save"));
-          set_response_visible (ADW_MESSAGE_DIALOG (self), "save", TRUE);
 
           g_free (body);
         }
 
-      gtk_widget_hide (GTK_WIDGET (self->page));
+      gtk_widget_set_visible (GTK_WIDGET (self->page), FALSE);
     }
   else
     {
@@ -463,29 +425,21 @@ panel_save_dialog_update (PanelSaveDialog *self)
 
       if (has_selected && has_unselected)
         {
+          adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (self), "save", _("Only _Save Selected"));
           adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (self), "save", ADW_RESPONSE_DESTRUCTIVE);
-          adw_message_dialog_set_response_label (ADW_MESSAGE_DIALOG (self), "save", _("Only _Save Selected"));
-          set_response_visible (ADW_MESSAGE_DIALOG (self), "save", TRUE);
-
-          set_response_visible (ADW_MESSAGE_DIALOG (self), "discard", FALSE);
         }
       else if (has_selected)
         {
+          adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (self), "save", _("Save All"));
           adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (self), "save", ADW_RESPONSE_SUGGESTED);
-          adw_message_dialog_set_response_label (ADW_MESSAGE_DIALOG (self), "save", _("Save All"));
-
-          set_response_visible (ADW_MESSAGE_DIALOG (self), "discard", FALSE);
         }
       else
         {
-          set_response_visible (ADW_MESSAGE_DIALOG (self), "save", FALSE);
-
+          adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (self), "discard", _("Discard All"));
           adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (self), "discard", ADW_RESPONSE_DESTRUCTIVE);
-          adw_message_dialog_set_response_label (ADW_MESSAGE_DIALOG (self), "discard", _("Discard All"));
-          set_response_visible (ADW_MESSAGE_DIALOG (self), "discard", TRUE);
         }
 
-      gtk_widget_show (GTK_WIDGET (self->page));
+      gtk_widget_set_visible (GTK_WIDGET (self->page), TRUE);
     }
 }
 
@@ -551,8 +505,6 @@ panel_save_dialog_run_async (PanelSaveDialog     *self,
   g_return_if_fail (PANEL_IS_SAVE_DIALOG (self));
   g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
 
-  g_object_ref_sink (self);
-
   if (cancellable == NULL)
     self->cancellable = g_cancellable_new ();
   else
@@ -623,3 +575,5 @@ panel_save_dialog_set_close_after_save (PanelSaveDialog *self,
       g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_CLOSE_AFTER_SAVE]);
     }
 }
+
+G_GNUC_END_IGNORE_DEPRECATIONS
